Structs
- Laser
Eyes Workspace Config - Configuration for a single workspace in laser-eyes mode
- Permissive
Workspace Config - Configuration for a single workspace in permissive mode
Enums
- Config
- Configuration for elf-magic from package.metadata.elf-magic
Functions
- resolve_
constants_ paths - Resolve constant override paths to absolute paths based on config file location
- resolve_
targets_ paths - Resolve target override paths to absolute paths based on config file location